require 'uu/os/gvc/component'
require 'uu/os/gvc/styleable'

module UU
  module OS
    module GVC

      # Button component.
      class Button < UU::OS::GVC::Component
        include UU::OS::GVC::Styleable

        # Flag if component is disabled.
        attr_accessor :disabled

        # Button icon UESURI refers to icon in image catalog.
        attr_accessor :icon_uri

        # Defines target window where the action URI will be opened - one of "CURRENT_WINDOW" (default),
        # "NEW_WINDOW", "DIALOG_WINDOW". For backward compatibility it's also possible to use older equivalents
        # "SELF", "NEW" and "MODAL".
        attr_accessor :target

        # Button text.
        attr_accessor :text

        # Button tooltip text.
        attr_accessor :tooltip

        # Button uri. Can contain valid UESURI or uri to external web page. Web page uris must
        # have one of supported schemas (http, https). External web pages is alway opened into
        # new window ( attribute target is ignored ).
        attr_accessor :action_uri

        # Button minimal width
        attr_accessor :min_width

        # Button maximal width
        attr_accessor :max_width

        def disabled
          attributes[:disabled]
        end

        def disabled=(disabled)
          attributes[:disabled] = disabled
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(icon_uri)
          attributes[:iconUri] = icon_uri
        end

        def target
          attributes[:target]
        end

        def target=(target)
          attributes[:target] = target
        end

        def text
          attributes[:text]
        end

        def text=(text)
          attributes[:text] = text
        end

        def tooltip
          attributes[:tooltip]
        end

        def tooltip=(tooltip)
          attributes[:tooltip] = tooltip
        end

        def action_uri
          attributes[:actionUri]
        end

        def action_uri=(action_uri)
          attributes[:actionUri] = action_uri
        end

        def max_width
          attributes[:maxWidth]
        end

        def max_width=(max_width)
          attributes[:maxWidth] = max_width
        end

        def min_width
          attributes[:minWidth]
        end

        def min_width=(min_width)
          attributes[:minWidth] = min_width
        end

      end

    end
  end
end
